% 
% Anagallis root system where the parameters are estimated based on 
% L. Kutschera 1960, p. 405. 
%
% Copyright 2008-2013 Daniel Leitner. See license.txt for details.
%

clear all
set(0,'RecursionLimit',10000);

% root system definition,all values are [mean, std], default std = 0.

p{1}.name = 'tap root';
p{1}.r = 4; % initial growth rate 
p{1}.lb = 1; % length of basal zone 
p{1}.la = 1.2; % length of apical zone
p{1}.ln = 0.8; % inter-root distacne
p{1}.nob = 40; % number of branches 
p{1}.a = 0.05; % root radius
p{1}.theta = 0; % angle between this root and successor
p{1}.color = [110/255,100/255,50/255]; % root color 
p{1}.tropism = [1,4,90*pi/180];  % tropism parameters [type, N, sigma], see tropism, tropismObjective
p{1}.dx = 0.25;  % resolution along the axis 
p{1}.successor = 2; % successor number, or [number, probability; number probability; ...]

p{2}.name = '1st order laterals';
p{2}.r = [1.5,0.15]; 
p{2}.lb = [0.4,0.1]; 
p{2}.la = [0.8,0.2];
p{2}.ln = [0.5,0.1]; 
p{2}.nob = [14,10];
p{2}.a = 0.03;
p{2}.theta = [70*pi/180, 3*pi/180];
p{2}.color = [140/255,125/255,40/255];
p{2}.tropism = [0,2,30*pi/180]; % plagiotropism
p{2}.dx = 0.1;
p{2}.successor = 3;

p{3}.name = '2nd order laterals';
p{3}.r = [2;0.2] ;
p{3}.lb = [0.1,0.01];               
p{3}.la = [0.1,0.01];         
p{3}.ln = 0.24;  
p{3}.nob = [2,2];            
p{3}.a = 0.02; 
p{3}.theta = [68*pi/180, 3*pi/180];
p{3}.color = [160/255,150/255,30/255];
p{3}.tropism = [1,2,45*pi/180]; % gravitropism
p{3}.dx = 0.1;
p{3}.successor = 4;

p{4}.name = '3rd order laterals';
p{4}.r  = [2, 0.2];                      
p{4}.la  = [0.4, 0.03];                   
p{4}.a  = 0.02;                
p{4}.theta = [68*pi/180, 3*pi/180];  
p{4}.color = [200/255,200/255,10/255];  
p{4}.tropism = [0,0,18*pi/180]; % no tropism (since N=0)                      
p{4}.dx = 0.1;

p = completeParameters(p);

% simulate root growth 
str = createRootSystem(); 
simtime = 17; % days 
tic
str = applyRules(str,simtime);
toc

% % analyse length 
% tic
% N=50;
% simtime = 17; % days
% str = createRootSystem();  
% for i = 1 : N
%     disp(i);
%     str = applyRules(str,simtime/N);
%     l(i) = getTotal(str,'l'); % store length
% end
% toc
% % plot total length versus time
% plot(linspace(0,simtime,N),l);
% xlabel('time (days)');
% ylabel('length (cm) ');

% plot final root system
figure;
plotTubes(str);

% % Movie 
% mtime = 10; % seconds
% simtime = 17; % days
% fview = @(t) view(t/mtime*360,0); % rotation
% makeMovie('Anagallis.avi',str,simtime,mtime,fview); 
