function len = growthFunction(t, p, pos, invert)
% growthFunction: determines root length at a given time
%
% Parameters:
% t             root age
% p             parameters p(1) = type, p(2:3) = additional parameters
% (pos)         global position
% (invert)      invert growth function (default = false)
%
% len           length of root
%
% Implemented so far: 
% type = 1 :negative exponential growth, p(2) intial growth rate, 
%           p(3) maximal root length 
% type = 2 :linear growth,  p(2) growth rate, p(3) maximal root length
%
% Copyright 2013 Daniel Leitner. See license.txt for details.
%

if nargin<4
    invert = false;
end

id = p(1);
r = p(2);
k = p(3);

if ~invert
    
    switch id
    
        case 1 % negative exponential
            
            len = k*(1-exp(-(r/k)*t));
            
        case 2 % constant until a maximal length is reached
            
            len = min(k,r * t);
            
        %
        % add further 
        %
        
        otherwise
            disp(id);
            
    end
        
else
    
    switch id
        
        case 1 % negative exponential
            k = k*1.001; % add a small value, so that k is reached in finite time
            len = t;
            t = - k/r*log(1-len/k);
            len = t;
            
        case 2 % constant until a maximal length is reached
            len = t;        
            t = len/r;            
            len = t;             
        
        otherwise % numerical inversion
            len = fzero(@(t_) growthFunction(t_,p,pos)-t,[0,3650]);
            
    end    
    
end

